@@ -132,26 +132,39 @@ static void
 initialize_enchant ()
 {
 	GModule *enchant;
+	gpointer funcptr;
 
-	enchant = g_module_open("libenchant.so", 0);
+	enchant = g_module_open("libenchant.so.1", 0);
 	if (enchant == NULL)
-		return;
+	{
+		enchant = g_module_open("libenchant.so", 0);
+		if (enchant == NULL)
+			return;
+	}
 
 	have_enchant = TRUE;
 
-	g_module_symbol(enchant, "enchant_broker_init",            (gpointer *) &enchant_broker_init);
-	g_module_symbol(enchant, "enchant_broker_free",            (gpointer *) &enchant_broker_free);
-	g_module_symbol(enchant, "enchant_broker_free_dict",       (gpointer *) &enchant_broker_free_dict);
-	g_module_symbol(enchant, "enchant_broker_list_dicts",      (gpointer *) &enchant_broker_list_dicts);
-	g_module_symbol(enchant, "enchant_broker_request_dict",    (gpointer *) &enchant_broker_request_dict);
+#define MODULE_SYMBOL(name, func) \
+	g_module_symbol(enchant, (name), &funcptr); \
+	(func) = funcptr;
 
-	g_module_symbol(enchant, "enchant_dict_add_to_personal",   (gpointer *) &enchant_dict_add_to_personal);
-	g_module_symbol(enchant, "enchant_dict_add_to_session",    (gpointer *) &enchant_dict_add_to_session);
-	g_module_symbol(enchant, "enchant_dict_check",             (gpointer *) &enchant_dict_check);
-	g_module_symbol(enchant, "enchant_dict_describe",          (gpointer *) &enchant_dict_describe);
-	g_module_symbol(enchant, "enchant_dict_free_suggestions",  (gpointer *) &enchant_dict_free_suggestions);
-	g_module_symbol(enchant, "enchant_dict_store_replacement", (gpointer *) &enchant_dict_store_replacement);
-	g_module_symbol(enchant, "enchant_dict_suggest",           (gpointer *) &enchant_dict_suggest);
+	MODULE_SYMBOL("enchant_broker_init", enchant_broker_init)
+	MODULE_SYMBOL("enchant_broker_free", enchant_broker_free)
+	MODULE_SYMBOL("enchant_broker_free_dict", enchant_broker_free_dict)
+	MODULE_SYMBOL("enchant_broker_list_dicts", enchant_broker_list_dicts)
+	MODULE_SYMBOL("enchant_broker_request_dict", enchant_broker_request_dict)
+
+	MODULE_SYMBOL("enchant_dict_add_to_personal", enchant_dict_add_to_personal)
+	MODULE_SYMBOL("enchant_dict_add_to_session", enchant_dict_add_to_session)
+	MODULE_SYMBOL("enchant_dict_check", enchant_dict_check)
+	MODULE_SYMBOL("enchant_dict_describe", enchant_dict_describe)
+	MODULE_SYMBOL("enchant_dict_free_suggestions",
+				  enchant_dict_free_suggestions)
+	MODULE_SYMBOL("enchant_dict_store_replacement",
+				  enchant_dict_store_replacement)
+	MODULE_SYMBOL("enchant_dict_suggest", enchant_dict_suggest)
+
+#undef MODULE_SYMBOL
 }
 
 static void
@@ -964,10 +977,11 @@ get_lang_from_dict_cb(const char * const lang_tag,
 static gchar *
 get_lang_from_dict(struct EnchantDict *dict)
 {
+	gchar *lang;
+
 	if (!have_enchant)
 		return NULL;
 
-	gchar *lang;
 	enchant_dict_describe(dict, get_lang_from_dict_cb, &lang);
 	return lang;
 }
@@ -1022,14 +1036,14 @@ dict_describe_cb(const char * const lang_tag,
 GSList *
 sexy_spell_entry_get_languages(const SexySpellEntry *entry)
 {
+	GSList *langs = NULL;
+
 	g_return_val_if_fail(entry != NULL, NULL);
 	g_return_val_if_fail(SEXY_IS_SPELL_ENTRY(entry), NULL);
 
 	if (enchant_broker_list_dicts == NULL)
 		return NULL;
 
-	GSList *langs = NULL;
-
 	if (!entry->priv->broker)
 		return NULL;
 
@@ -1086,6 +1100,8 @@ sexy_spell_entry_language_is_active(const SexySpellEntry *entry,
 gboolean
 sexy_spell_entry_activate_language(SexySpellEntry *entry, const gchar *lang, GError **error)
 {
+	gboolean ret;
+
 	g_return_val_if_fail(entry != NULL, FALSE);
 	g_return_val_if_fail(SEXY_IS_SPELL_ENTRY(entry), FALSE);
 	g_return_val_if_fail(lang != NULL && lang != '\0', FALSE);
@@ -1093,8 +1109,6 @@ sexy_spell_entry_activate_language(SexySpellEntry *entry, const gchar *lang, GEr
 	if (!have_enchant)
 		return FALSE;
 
-	gboolean ret;
-
 	if (error)
 		g_return_val_if_fail(*error == NULL, FALSE);
 
